![Icon](images/icon@128.png)
# scappamento
[![License](https://img.shields.io/github/license/LorenzoBunino/scappamento)]()
[![Build Status](https://travis-ci.com/LorenzoBunino/scappamento.svg?branch=master)](https://travis-ci.com/LorenzoBunino/scappamento)
[![PyPI version](https://badge.fury.io/py/scappamento.svg)](https://badge.fury.io/py/scappamento)
#### B2B automation for music stores

**scappamento** is a Python tool that acts as an intermediary between suppliers and ERP software.

Supported suppliers / platforms:
- [x] Yamaha
- [x] Fender
- [x] Frenexport
- [ ] Proel (WIP)
- [x] Suonostore
- [ ] MusicPool (WIP, broken)
- [x] acquistinretepa
- [x] Mogar (Encoding conversion)

:broccoli:

New commit labels: `fix`, `feat`, `test`, `refactor`, `perf`